@@ -75,6 +75,7 @@ class Door(_BaseWithShade):
         assert data['type'] == 'Door', 'Expected Door dictionary. ' \
             'Got {}.'.format(data['type'])
 
+        # serialize the door
         is_glass = data['is_glass'] if 'is_glass' in data else False
         if data['boundary_condition']['type'] == 'Outdoors':
             boundary_condition = Outdoors.from_dict(data['boundary_condition'])
@@ -92,6 +93,7 @@ class Door(_BaseWithShade):
             door.user_data = data['user_data']
         door._recover_shades_from_dict(data)
 
+        # assign extension properties
         if data['properties']['type'] == 'DoorProperties':
             door.properties._load_extension_attr_from_dict(data['properties'])
         return door
@@ -258,7 +260,6 @@ class Door(_BaseWithShade):
                            in self._boundary_condition._boundary_condition_objects)
             self._boundary_condition = Surface(new_bc_objs, True)
 
-
     def set_adjacency(self, other_door):
         """Set this door to be adjacent to another (and vice versa).
 
@@ -377,6 +378,18 @@ class Door(_BaseWithShade):
         self.scale_shades(factor, origin)
         self.properties.scale(factor, origin)
 
+    def remove_colinear_vertices(self, tolerance=0.01):
+        """Remove all colinear and duplicate vertices from this object's geometry.
+
+        Note that this does not affect any assigned Shades.
+
+        Args:
+            tolerance: The minimum distance between a vertex and the boundary segments
+                at which point the vertex is considered colinear. Default: 0.01,
+                suitable for objects in meters.
+        """
+        self._geometry = self.geometry.remove_colinear_vertices(tolerance)
+
     def check_planar(self, tolerance=0.01, raise_exception=True):
         """Check whether all of the Door's vertices lie within the same plane.
 
